==> nextcloud-app-bookmarks-1%3A15.1.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/mk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Link copied to clipboard" : "Линкот е копиран во клипборд",
    "Details" : "Детали",
    "Rename" : "Преименувај",
    "Copy link" : "Копирај линк",
    "Move" : "Премести",
    "Delete selection" : "Избриши ги селектираните",
    "Select all" : "Избери се",
    "RSS feed copied" : "RSS канал копиран",
    "Go back" : "Назад",
    "Share folder" : "Сподели папка",
    "New" : "Ново",
    "New folder" : "Нова папка",
    "Search" : "Барај",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "Rename folder" : "Преименувај папка",
    "Submit" : "Испрати",
    "Cancel" : "Откажи",
    "Recent" : "Неодамнешни",
    "Shared with you" : "Споделено со вас",
    "Files" : "Датотеки",
    "Delete" : "Избриши",
    "Need help?" : "Ви треба помош?",
    "Created on {date}" : "Креиран на {date}",
    "Title" : "Наслов",
    "Link" : "Линк",
    "Tags" : "Ознаки",
    "Notes" : "Белешки",
    "Download file" : "Преземи датотека",
    "Link copied" : "Линкот е копиран",
    "Owner" : "Сопственик",
    "Sharing" : "Споделување",
    "Select a user or group" : "Избери корисник или група",
    "Share link" : "Сподели линк",
    "Copy RSS feed" : "Копирај RSS канал",
    "Create public link" : "Креирај јавен линк",
    "Allow editing" : "Овозможи уредување",
    "Allow resharing" : "Дозволи повторно споделување",
    "Remove share" : "Отстрани споделување",
    "Failed to save settings" : "Неуспешно зачувување на параметрите",
    "Failed to load settings" : "Неуспешно вчитување на параметрите",
    "Privacy" : "Приватност",
    "Folder" : "Папка",
    "Save" : "Зачувај",
    "What's new?" : "Што е ново",
    "Failed to load tags" : "Неуспешно вчитување на ознаки"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-bookmarks-1%3A16.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/mk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Link copied to clipboard" : "Линкот е копиран во клипборд",
    "Details" : "Детали",
    "Rename" : "Преименувај",
    "Copy link" : "Копирај линк",
    "Move" : "Премести",
    "Delete selection" : "Избриши ги селектираните",
    "Select all" : "Избери се",
    "RSS feed copied" : "RSS канал копиран",
    "Go back" : "Назад",
    "Share folder" : "Сподели папка",
    "New" : "Ново",
    "New folder" : "Нова папка",
    "Search" : "Барај",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "Enter a link" : "Внеси линк",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "Shared by {user}" : "Споделено од {user}",
    "Rename folder" : "Преименувај папка",
    "Move folder" : "Премести папка",
    "Submit" : "Испрати",
    "Cancel" : "Откажи",
    "Recent" : "Неодамнешни",
    "Shared with you" : "Споделено со вас",
    "Files" : "Датотеки",
    "Delete" : "Избриши",
    "Need help?" : "Ви треба помош?",
    "Created on {date}" : "Креиран на {date}",
    "Title" : "Наслов",
    "Link" : "Линк",
    "Tags" : "Ознаки",
    "Notes" : "Белешки",
    "Download file" : "Преземи датотека",
    "Link copied" : "Линкот е копиран",
    "Owner" : "Сопственик",
    "Sharing" : "Споделување",
    "Select a user or group" : "Избери корисник или група",
    "Share link" : "Сподели линк",
    "Copy RSS feed" : "Копирај RSS канал",
    "Create public link" : "Креирај јавен линк",
    "Allow editing" : "Овозможи уредување",
    "Allow resharing" : "Дозволи повторно споделување",
    "Remove share" : "Отстрани споделување",
    "Failed to save settings" : "Неуспешно зачувување на параметрите",
    "Failed to load settings" : "Неуспешно вчитување на параметрите",
    "Privacy" : "Приватност",
    "Folder" : "Папка",
    "Save" : "Зачувај",
    "What's new?" : "Што е ново",
    "Failed to load tags" : "Неуспешно вчитување на ознаки"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
